@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.004';
+$App::Cme::Common::VERSION = '1.005';
 use strict;
 use warnings;
 use 5.10.1;
@@ -92,7 +92,7 @@ sub process_args {
     if ($config_file and not -e $config_file) {
         $warn_msg = "Warning: file '$config_file' does not exists.";
     }
-    if ($appli_info->{$application}{allow_config_file_override}) {
+    if ($warn_msg and $appli_info->{$application}{allow_config_file_override}) {
         $warn_msg .=" You may need to write this command with '~~' argument. I.e. try "
             ."something like 'cme $command $application ~~ $config_file'";
     }
@@ -229,7 +229,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 SYNOPSIS
 
